@@ -35,9 +35,7 @@ protected:
     virtual void paint(QPainter* pPainter, const QStyleOptionViewItem& option, const QModelIndex& index) const;
 
 private:
-    QString formatSize(qint64 size) const;
-
-    QModelIndex m_SelectedIndex;        // The index which will be drawn as bold
+    QModelIndex m_SelectedIndex;        ///< The index which will be drawn as bold
 };
 
 #endif // DELEGATE_H
